#!/bin/sh
#######################################################################
#	Copyright ( C ) 1997, Silicon Graphics, Inc.
# These coded instructions, statements, and computer programs  contain
# unpublished  proprietary  information of Silicon Graphics, Inc., and
# are protected by Federal copyright law.  They  may  not be disclosed
# to  third  parties  or copied or duplicated in any form, in whole or
# in part, without the prior written consent of Silicon Graphics, Inc.
#######################################################################
#
#	Screen Area install script for SGI
#	modified for IRIX 6.2 (or greater)
#	set verbose
#	expects to run in the same directory as the driver files.
#
#######################################################################
echo ""
echo "Beginning AutoCAD MoleMode/ScreenArea driver installation..."
echo ""
RebuildKernel="false"
umask 000
#
#######################################################################
# Must have super-user privledges
#######################################################################
set `id`
if test "$1" != "uid=0(root)" ; then
	echo "*** You must have super-user privleges to run '$0' ***"
	echo "*** To do so, enter 'su' at the prompt then '$0'    ***"
	exit 1
fi
#
#######################################################################
# Check for 6.x O/S
#######################################################################
case `uname -r` in
	6.*)
	echo "- `uname -s` `uname -r` O/S detected."
	if test -f /etc/init.d/nds ; then
		echo "- eoe.sw.nds subsystem is installed."
	else
		echo "\nError: eoe.sw.nds subsystem is not installed..."
		echo "       Please install 'eoe.sw.nds' from your `uname -s` `uname -r` CD"
		echo "       then re-run $0."
		echo "\nIf you do not have your `uname -s` `uname -r` CD, you may try running"
		echo "the 'drivers.sh' shell script in this directory."
		exit 2
	fi
	;;

	5.*)
	echo "- `uname -s` `uname -r` is not supported with this package..."
	echo "  use /opt/acad13/support/mole/inst.sh version instead."
	exit 2
	;;

	*)
	echo "*** Not supported on `uname -r` platform ***"
	exit 3
        ;;
esac
#
#######################################################################
#	Make the special device files for the pseudo-mouse.
#######################################################################
echo "...making pseudo-mouse device files."
#
rm -f /dev/input/mdev
/etc/mknod /dev/input/mdev c 258 0
chmod +rw /dev/input/mdev
#
rm -f /dev/input/bmouse
/etc/mknod /dev/input/bmouse c 258 1
chmod +rw /dev/input/bmouse
#
#######################################################################
#	The doio program must be setuid root.
#	we place it by default in /etc/acad_mole which is probably 
#	mounted so the chmod, chown will work.
#######################################################################
echo "...installing screen area driver program."
if test -d /etc/acad_mole ; then
	echo "- /etc/acad_mole directory already exists."
else
	mkdir -p /etc/acad_mole
fi
cp doio /etc/acad_mole/doio
chown root.sys /etc/acad_mole/doio
chmod u+sx,go+x,ugo-w /etc/acad_mole/doio
#
#######################################################################
#	Now tune the kernel to allow setuid() operation of doio
#######################################################################
GFILE="/var/sysgen/stune"
istr="nosuidshells = 0"
str=`grep nosuidshells $GFILE`;
if test "$str" = "$istr" ; then
        echo "...kernel suid parameter previously set."
else
        echo "...setting kernel suid parameter."
	echo "******************************************"	>> $GFILE
	echo "* Allow setuid for AutoCAD R13 Screen Area"	>> $GFILE
	echo "******************************************"	>> $GFILE
	echo "$istr"						>> $GFILE
	RebuildKernel="true"
fi
#
#######################################################################
#	Copy in X11 config file to use the pseudo-mouse
#######################################################################
if test -d /usr/lib/X11/input/config ; then
	echo ".../usr/lib/X11/input/config directory already exists."
else
	mkdir -m 755 -p /usr/lib/X11/input/config >& /dev/null
fi
cp bogus_mouse /usr/lib/X11/input/config
#
#######################################################################
#	Now (auto)config the kernel
#######################################################################
if test "$RebuildKernel" = "true" ; then
	echo ""
	echo "Automatically re-configuring the IRIX kernel for Screen Area."
	echo "Please stand by..."
	/etc/autoconfig
	echo ""
	echo "You will now need to re-boot you system for the Screen Area"
	echo "drivers you have just installed to be loaded."
fi
echo ""
echo "The AutoCAD Screen Area drivers have been successfully installed."
echo "You can test the Screen Area drivers with the 'testit' program"
echo "located in this directory, as follows:"
echo "	> su"
echo "	# cd /opt/acad13/support/mole.6.x"
echo "	# ./testit"
echo ""
echo "Successful operation is indicated by the system cursor traversing"
echo "the screen, followed by a message."
echo ""
echo "You may also have to re-configure AutoCAD's digitizer driver to"
echo "enable Screen Area capabilities.  If you have not already configured"
echo "a digitizer driver for AutoCAD, here are some helpful tips:"
echo ""
echo "    1. You should try to use serial port 2 because port 1 is configured"
echo "	     by default as a terminal device."
echo ""
echo "    2. In the 'System Manager', be sure that the tablet's Serial Port"
echo "       is 'Available' in the 'Port Setup' tool.  If it is NOT available"
echo "       select the port and then 'Disconnect...' it."
echo ""
echo "    3. You should also ensure that AutoCAD has read/write access to"
echo "       the digitizer port.  Check this with:"
echo "        ls -l /dev/ttyd1"
echo "        - or -"
echo "        ls -l /dev/ttyd2"
echo ""
echo "       If you DO NOT see the following file permissions:"
echo "          crw-rw-rw- ... /dev/ttydX"
echo "          ^^^ ^^ ^^ Note: these items are required"
echo ""
echo "       Then correct them as follows:"
echo "          chmod +rw /dev/ttydX  (where X is 1 or 2 as required)"
echo ""
echo ""
echo "The latest version of this file may be found on the following web page:"
echo "	http://reality.sgi.com/autocad/Digitizers.html"
echo ""
